@@ -1,11 +1,14 @@
 package WebAPI::DBIC::Resource::GenericItemDBIC;
-$WebAPI::DBIC::Resource::GenericItemDBIC::VERSION = '0.001000'; # TRIAL
+$WebAPI::DBIC::Resource::GenericItemDBIC::VERSION = '0.001005'; # TRIAL
 use Moo;
 use namespace::clean;
 
 extends 'WebAPI::DBIC::Resource::Base';
 with    'WebAPI::DBIC::Role::JsonEncoder',
         'WebAPI::DBIC::Role::JsonParams',
+        'WebAPI::DBIC::Resource::Role::Router',
+        'WebAPI::DBIC::Resource::Role::Identity',
+        'WebAPI::DBIC::Resource::Role::Relationship',
         'WebAPI::DBIC::Resource::Role::DBIC',
         'WebAPI::DBIC::Resource::Role::DBICException',
         'WebAPI::DBIC::Resource::Role::DBICAuth',
@@ -28,7 +31,7 @@ WebAPI::DBIC::Resource::GenericItemDBIC
 
 =head1 VERSION
 
-version 0.001000
+version 0.001005
 
 =head1 AUTHOR
 
