@@ -1,11 +1,14 @@
 package WebAPI::DBIC::Resource::GenericSetDBIC;
-$WebAPI::DBIC::Resource::GenericSetDBIC::VERSION = '0.001000'; # TRIAL
+$WebAPI::DBIC::Resource::GenericSetDBIC::VERSION = '0.001005'; # TRIAL
 use Moo;
 use namespace::clean;
 
 extends 'WebAPI::DBIC::Resource::Base';
 with    'WebAPI::DBIC::Role::JsonEncoder',
         'WebAPI::DBIC::Role::JsonParams',
+        'WebAPI::DBIC::Resource::Role::Router',
+        'WebAPI::DBIC::Resource::Role::Identity',
+        'WebAPI::DBIC::Resource::Role::Relationship',
         'WebAPI::DBIC::Resource::Role::DBIC',
         'WebAPI::DBIC::Resource::Role::DBICException',
         'WebAPI::DBIC::Resource::Role::DBICAuth',
@@ -29,7 +32,7 @@ WebAPI::DBIC::Resource::GenericSetDBIC
 
 =head1 VERSION
 
-version 0.001000
+version 0.001005
 
 =head1 AUTHOR
 
