@@ -1,9 +1,14 @@
 package WebAPI::HTTP::Throwable::Factory;
-$WebAPI::HTTP::Throwable::Factory::VERSION = '0.001000'; # TRIAL
+$WebAPI::HTTP::Throwable::Factory::VERSION = '0.001005'; # TRIAL
+use strict;
+use warnings;
+
 use parent 'HTTP::Throwable::Factory';
+
 use Carp qw(carp cluck);
 use JSON::MaybeXS qw(JSON);
 
+
 sub extra_roles {
     return (
         'WebAPI::HTTP::Throwable::Role::JSONBody', # remove HTTP::Throwable::Role::TextBody
@@ -45,7 +50,7 @@ WebAPI::HTTP::Throwable::Factory
 
 =head1 VERSION
 
-version 0.001000
+version 0.001005
 
 =head1 AUTHOR
 
